@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.49 2003/07/29 14:33:19 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.57 2003/10/10 14:18:21 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -73,6 +73,9 @@ char *dtype_desc[] = {         /* Tooltips for each display mode value. */
     N_("Set display type to scientific format")
 };
 
+char *hyp_desc = N_("Set hyperbolic option for trigonometric functions");
+char *inv_desc = N_("Set inverse option for trigonometric functions");
+
 char *mode_str[]  = {          /* Strings for each mode value. */
     N_("BASIC"), N_("FINANCIAL"), N_("SCIENTIFIC")
 };
@@ -136,8 +139,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 1. */
 {
     N_("7"),
-    N_("Numeric 7"),
     NULL,
+    N_("Numeric 7"),
     { 0,     0,        0,           0,      0 },
     { GDK_7, GDK_KP_7, GDK_KP_Home, GDK_R7, 0 },
     '7',
@@ -146,8 +149,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("8"),
-    N_("Numeric 8"),
     NULL,
+    N_("Numeric 8"),
     { 0,     0,        0,         0,      0 },
     { GDK_8, GDK_KP_8, GDK_KP_Up, 0 },
     '8',
@@ -156,8 +159,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("9"),
-    N_("Numeric 9"),
     NULL,
+    N_("Numeric 9"),
     { 0,     0,        0,              0,      0 },
     { GDK_9, GDK_KP_9, GDK_KP_Page_Up, GDK_R9, 0 },
     '9',
@@ -198,8 +201,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("CE"),
     N_("Clear displayed value"),
     N_("Clear entry"),
-    { GDK_CONTROL_MASK, 0 },
-    { GDK_BackSpace, 0 },
+    { GDK_CONTROL_MASK, 0,          0 },
+    { GDK_BackSpace,    GDK_Escape, 0 },
     '\013',
     M_NONE,
     do_clear_entry
@@ -218,8 +221,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 2. */
 {
     N_("4"),
-    N_("Numeric 4"),
     NULL,
+    N_("Numeric 4"),
     { 0,     0,        0,           0,        0 },
     { GDK_4, GDK_KP_4, GDK_KP_Left, 0 },
     '4',
@@ -228,8 +231,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("5"),
-    N_("Numeric 5"),
     NULL,
+    N_("Numeric 5"),
     { 0,     0,        0,            0,       0 },
     { GDK_5, GDK_KP_5, GDK_KP_Begin, GDK_R11, 0 },
     '5',
@@ -238,8 +241,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("6"),
-    N_("Numeric 6"),
     NULL,
+    N_("Numeric 6"),
     { 0,     0,        0,            0,         0 },
     { GDK_6, GDK_KP_6, GDK_KP_Right, 0 },
     '6',
@@ -270,9 +273,9 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("+/-"),
     N_("Change sign"),
     NULL,
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_C, 0 },
-    'C',
+    { 0,     0 },
+    { GDK_c, 0 },
+    'c',
     M_NONE,
     do_immed
 },
@@ -300,8 +303,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 3. */
 {
     N_("1"),
-    N_("Numeric 1"),
     NULL,
+    N_("Numeric 1"),
     { 0,     0,        0,          0,       0 },
     { GDK_1, GDK_KP_1, GDK_KP_End, GDK_R13, 0 },
     '1',
@@ -310,8 +313,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("2"),
-    N_("Numeric 2"),
     NULL,
+    N_("Numeric 2"),
     { 0,     0,        0,           0,        0 }, 
     { GDK_2, GDK_KP_2, GDK_KP_Down, 0 },
     '2',
@@ -320,8 +323,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },    
 {     
     N_("3"),
-    N_("Numeric 3"),
     NULL,
+    N_("Numeric 3"),
     { 0,     0,        0,                0,       0 },
     { GDK_3, GDK_KP_3, GDK_KP_Page_Down, GDK_R15, 0 },
     '3',
@@ -382,8 +385,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 4. */
 {
     N_("0"),
-    N_("Numeric 0"),
     NULL,
+    N_("Numeric 0"),
     { 0,     0,        0,             0 },
     { GDK_0, GDK_KP_0, GDK_KP_Insert, 0 },
     '0',
@@ -414,8 +417,8 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     N_("+"),
     N_("Add"),
     NULL,
-    { GDK_SHIFT_MASK, 0,          0 },
-    { GDK_plus,       GDK_KP_Add, 0 },
+    { GDK_SHIFT_MASK, 0,        0,          0 },
+    { GDK_plus,       GDK_plus, GDK_KP_Add, 0 },
     '+',
     M_NONE,
     do_calc
@@ -490,9 +493,9 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
     N_("Ddb"),
     N_("Double-declining depreciation"),
     NULL,
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_D, 0 },
-    'D',
+    { 0,     0 },
+    { GDK_d, 0 },
+    'd',
     M_NONE,
     do_business
 },
@@ -728,9 +731,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("Acc"),
     N_("Set accuracy from 0 to 9 numeric places"),
     N_("Accuracy"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_A, 0 },
-    'A',
+    { 0,     0 },
+    { GDK_a, 0 },
+    'a',
     M_ACC,
     do_pending
 },
@@ -750,9 +753,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("Fun"),
     N_("User-defined functions"),
     NULL,
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_F, 0 },
-    'F',
+    { 0,     0 },
+    { GDK_f, 0 },
+    'f',
     M_FUN,
     do_pending
 },
@@ -760,14 +763,14 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("Exp"),
     N_("Enter an exponential number"),
     N_("Exponential"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_E, 0 },
-    'E',
+    { 0,     0 },
+    { GDK_e, 0 },
+    'e',
     M_NONE,
     do_expno
 },
 {
-    N_("e<sup>x</sup>"),
+    N_("<i>e</i><sup>x</sup>"),
     N_("e to the power of displayed value"),
     N_("E to the x"),
     { GDK_SHIFT_MASK, 0 },
@@ -822,9 +825,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("D"),
     N_("Hexadecimal digit D"),
     NULL,
-    { 0, 0 },
-    { GDK_d, 0 },
-    'd',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_D,          0 },
+    'D',
     M_NONE,
     do_number
 },
@@ -832,9 +835,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("E"),
     N_("Hexadecimal digit E"),
     NULL,
-    { 0, 0 },
-    { GDK_e, 0 },
-    'e',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_E,          0 },
+    'E',
     M_NONE,
     do_number
 },
@@ -842,9 +845,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("F"),
     N_("Hexadecimal digit F"),
     NULL,
-    { 0, 0 },
-    { GDK_f, 0 },
-    'f',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_F,          0 },
+    'F',
     M_NONE,
     do_number
 },
@@ -904,9 +907,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("A"),
     N_("Hexadecimal digit A"),
     NULL,
-    { 0, 0 },
-    { GDK_a, 0 },
-    'a',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_A,          0 },
+    'A',
     M_NONE,
     do_number
 },
@@ -914,9 +917,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("B"),
     N_("Hexadecimal digit B"),
     NULL,
-    { 0, 0 },
-    { GDK_b, 0 },
-    'b',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_B,          0 },
+    'B',
     M_NONE,
     do_number
 },    
@@ -924,16 +927,16 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     N_("C"),
     N_("Hexadecimal digit C"),
     NULL,
-    { 0, 0 },
-    { GDK_c, 0 },
-    'c',
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_C,          0 },
+    'C',
     M_NONE,
     do_number
 },
 {
     N_("Or"),
     N_("Logical OR"),
-    NULL,
+    "logical OR",
     { GDK_SHIFT_MASK, 0 },
     { GDK_bar, 0 },
     '|',
@@ -1014,6 +1017,8 @@ do_calctool(int argc, char **argv)
         }
     }
 
+    v->radix_char = get_radix_char();   /* Locale specific radix character. */
+
     init_text();               /* Setup text strings depending upon language. */
     init_vars();               /* Setup default values for variables. */
     load_resources();          /* Get resources from various places. */
