@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.38 2003/07/25 21:33:32 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.41 2003/10/02 19:16:16 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -244,6 +244,7 @@ struct calcVars {                      /* Calctool variables and options. */
     char opstr[5];                     /* Operand string during pending op. */
     char *progname;                    /* Name of this program. */
     char pstr[5];                      /* Current button text string. */
+    char radix_char;                   /* Locale specific radix character. */
     char *shelf;                       /* PUT selection shelf contents. */
     char snum[MAX_DIGITS+1];           /* Scratchpad for scientific numbers. */
     char *titleline;                   /* Value of titleline (if present). */
@@ -311,6 +312,7 @@ struct button *copy_button_info(struct button *);
 
 char *button_str(int);
 char *convert(char *);
+char get_numeric_sep();
 char *get_resource(enum res_type);
 char *make_number(int *, int, BOOLEAN, BOOLEAN);
 char *set_bool(int);
